@@ -47,11 +47,15 @@ def evaluate_model(model, data_loader, dim, loss, argmax=False, device='cuda'):
         with torch.no_grad():
             out = model(torch.cat((data_batch[:, :, :dim], data_batch[:, :, dim:2*dim]), 2), data_batch[:, :, -1])
         if argmax:
-            pred = pred.argmax(1)
+            pred = torch.argmax(out, dim=1)
         pred.append(out); true.append(label)
     pred = torch.cat(pred, 0).squeeze()
     true = torch.cat(true, 0).squeeze()
-    return loss(pred, true)
+    try:
+        return loss(pred, true)
+    except:
+        return loss(pred, true.long())    
+
 
 def predict(test_loader, device, model, model_type, dim):
     """
