@@ -249,7 +249,7 @@ class mtse:
 
     
     def train(self, lossf='rmse', plot_results=True, save_plot=True, x_start=10, argmax=False, CEweights=None,
-              predict_strategy=None, save_strategy='best', val_loss_threshold=100., n_iters=100):
+              predict_strategy=None, save_strategy='best', val_loss_threshold=100., n_iters=100, val_loss_fn=None):
         """
         Parameters
         ----------
@@ -289,6 +289,8 @@ class mtse:
             the minimum loss value to reach before saving the best model (default is 100.)
         n_iters : int, optional
             number of epochs (default is 100)
+        val_loss_fn : NoneType or Callable, optional
+            if None, same as the loss function; if a function, it is used to compute the validation loss
 
         Returns
         -------
@@ -299,6 +301,8 @@ class mtse:
         NotImplementedError, ValueError
         """
 
+        val_loss_fn = val_loss_fn if val_loss_fn is not None else lossf
+
         print('\n### Training ###')
         
         torch.backends.cudnn.enabled=False
@@ -333,7 +337,7 @@ class mtse:
                 loss.backward()
                 self.optimizer.step()
 
-            val_loss = evaluate_model(self.ts_encoder, self.val_loader, dim=self.n_ts, loss=criterion, argmax=argmax, device=self.device)
+            val_loss = evaluate_model(self.ts_encoder, self.val_loader, dim=self.n_ts, loss=val_loss_fn, argmax=argmax, device=self.device)
             train_losses.append(train_loss/train_n); val_losses.append(val_loss)
             self.scheduler.step(val_loss)
             total_time += time.time() - start_time
